/* ============================================================================================================================================= /
 * LIBRARY:         Gestione Input
 * FILE:            Manage_input.h
 * LAST REV:        1.2
 * AUTHOR:          Ivo Colleoni
 * DEVICE:          PIC18F
 * CREATED:         12/09/2013
 * UPDATED:         03/12/2013
 *
 * DESCRIP:         Parametri e prototipi per libreria Manage_input.c
 * ============================================================================================================================================= /
 * Change History:
 * Rev.             Date                Changes
 * 1.2              03/12/2013          Inserite costati di configurazione ritardi
 * 1.1              27/09/2013          Inserita costante PRESSED per indicare se i pulsanti chiudono a GND o a VCC
 * 1.0              12/09/2013
/* ============================================================================================================================================ */

/* CONTROLLI DI COMPILAZIONE ================================================================================================================== */

#ifndef    PRESSED
    #error Definire PRESSED (logica dei pulsanti)                                       // errore se pressed non  definito
#endif

#if (PRESSED>1)                                                        
    #error PRESSED pu valere solo 0 o 1 (logica dei pulsanti)
#endif

#ifndef N                                                                               // se N non  definito imposto 5
    #define N 5
#endif

/* PROTOTIPI E DOCUMENTAZIONE ================================================================================================================= */

/** @file Manage_input.c
 * Libreria per la gestione di pulsanti.
 * - Per un corretto funzionamento:
 *  + Includere la libreria Delay.c prima delle libreria Manage_input.c
 *  + Definire la frequenza del clock in MHz (XTAL_FREQ)
 * - Files:
 *  + Manage_input.c: Codice funzioni
 *  + Manage_input.h: Parametri e prototipi
 *  + Manage_input_settings.h: Impostazioni specifiche per progetto
 */

/**
 * Gestisce i pulsanti in ingresso. \n
 * Se il pulsante che si trova sull'ingresso indicato in _mask sulla porta indicata in _address  premuto torna 1 \n
 * Gestione pressione multipla: dopo N pressioni continue passa a pressione rapida
 * @param   *_address: indirizzo della PORT dei tasti
 * @param   _mask: maschera per lettura bit dello switch. es: &PORTA,1 o mnemonico
 * @return  
 *          - 1: tasto premuto
 *          - 0: tasto non premuto
 *
 * @note    dichiarare il valore di N: numero di pressioni continue prima di passare all'incremento veloce  \n
 *          dichiarare PRESSED: 0 se i pulsanti chiudono a GND 1 se i pulsanti chiudono a VCC
 */
unsigned char Debounce_multi(unsigned char *_address, unsigned char _mask);

/**
 * Gestisce i pulsanti in ingresso. \n
 * Se il pulsante che si trova sull'ingresso indicato in _mask sulla porta indicata in _address  premuto torna 1 \n
 * Gestione pressione singola (dopo la prima pressione le successive non vengono considerate fino al rilascio del tasto)
 * @param   *_address: indirizzo della PORT dei tasti
 * @param   _mask: maschera per lettura bit dello switch. es: &PORTA,1 o mnemonico
 * @return  
 *          - 1: tasto premuto
 *          - 0: tasto non premuto
 * @note    dichiarare PRESSED: 0 se i pulsanti chiudono a GND 1 se i pulsanti chiudono a VCC
 *
 */
unsigned char Debounce_single(unsigned char *_address, unsigned char _mask);

/**
 * Legge da tastiera 4x3 e 4x4 e restituisce il valore del tasto premuto, se non viene premuto nessun tasto viene restituito 0xFF.
 * Integra antirimbalzo ed evita la pressione multipla dei tasti (se si tiene premuto un tasto verr  letto solamente una volta)
 * @param   void
 * @retun   
 *          - 0xFF se non  premuto nessun tasto
 *          - numeri da 0 a 9 per i tasti corrispondenti, *->A, #->B ....               
 * @note    Collegamento standard: colonne sui bit da 0 a 3 e righe sui bit da 4 a 7 \n
 *          Definire su quale porta  collegata la tastiera mediante #define: \n
 *          #define COLUMN LATx  \n
 *          #define ROW (PORTx &0b11110000): mascherare solo i bit dedicati alle righe \n
 *          se non si utilizza il collegamento standard modificare gli array delle righe e delle colonne come opportuno  \n
 *          SE SI UTILIZZA QUESTA FUNZIONE DECOMMENTARE //#define KEYPAD_ON IN Manage_input.h
 */
unsigned char Read_keypad(void);

