/* ============================================================================================================================================= /
 * LIBRARY:         Gestione PGA2311, PGA2310, PGA2320
 * FILE:            PGA23xx.h
 * LAST REV:        1.0
 * AUTHOR:          Ivo Colleoni
 * DEVICE:          PIC18F
 * CREATED:         11/08/2017
 * UPDATED:          
 *
 * DESCRIP:         Parametri e prototipi per libreria PGA23xx.c
/* ============================================================================================================================================ */

/* CONTROLLI DI COMPILAZIONE ================================================================================================================== */

#ifndef SPI
    #error  Includere SPI_init.c
#endif

#ifdef PGA23xx_SPI_MODULE_1                                                             // Ridefinisco le chiamate alle funzioni a seconda del modulo I2C usato
    #ifndef SPI_MODULE_1
        #error SPI_MODULE_1 non abilitato in SPI_init_settings.h
    #endif
    
    #define _PGA23xx_SPI_enable         SPI_enable
    #define _PGA23xx_SPI_disable        SPI_disable
    #define _PGA23xx_SPI_send_byte      SPI_send_byte
    #define _PGA23xx_SPI_receive_byte   SPI_receive_byte

#elif defined PGA23xx_SPI_MODULE_2
    #ifndef SPI_MODULE_2
        #error SPI_MODULE_2 non abilitato in SPI_init_settings.h
    #endif
    
    #define _PGA23xx_SPI_enable         SPI2_enable
    #define _PGA23xx_SPI_disable        SPI2_disable
    #define _PGA23xx_SPI_send_byte      SPI2_send_byte
    #define _PGA23xx_SPI_receive_byte   SPI2_receive_byte

#else
    #error Definire il modulo SPI da utilizzare per PGA23xx
#endif
         

/* COSTANTI  ================================================================================================================================== */
#define PGA23xx_MUTE_ON             0
#define PGA23xx_MUTE_OFF            1
#define PGA23xx_ZCEN_ON             1
#define PGA23xx_ZCEN_OFF            0             

/* PROTOTIPI E DOCUMENTAZIONE ================================================================================================================= */

/** @file PGA23xx.c
 * Libreria per la gestione del chip PGA23xx
 * - Per un corretto funzionamento:
 *    + Includere la libreria SPI_init.c prima delle libreria PGA23xx.c
 *    + Impostare il modulo SPI da utilizzare per l'PGA23xx in PGA23xx_settings.h
 *    + Abilitare il modulo SPI utilizzato in SPI_init_settings.h
 *    + Definire il clock utilizzato in SPI_init_settings.h
 *    + Inizializzare il modulo SPI e il PGA23xx con la funzione PGAxx_enable()
 *    + Se si utilizzano pi device in SPI disabilitare il modulo SPI tramite funzione PGA23xx_disable() e riabilitarlo per il nuovo modulo
 *    (i parametri di comunicazione potrebbero essere diversi). In alternativa impostare direttamente nel programma principale il modulo SPI con le funzioni
 *    SPI_enable() e SPI2_enable()
 * - Files:
 *  + PGA23xx.c: Codice funzioni
 *  + PGA23xx.h: Parametri e prototipi
 *  + PGA23xx_settings.h: Impostazioni specifiche per progetto
 */

/** 
 * Abilita il modulo SPI e ne imposta i parametri
 * @param   void
 * @return  void
 */  
void PGA23xx_enable(void);

/** 
 * Disabilita il modulo SPI e ne imposta i parametri
 * @param   void
 * @return  void
 */ 
void PGA23xx_disable(void);  

/** 
 * Disabilita il modulo SPI e ne imposta i parametri
 * @param   _r: valore da impostare nel registro per il canale sinistro (unsigned char 0 = mute, 1= -95.5db 255 = +31.5db)
 * @param   _l: valore da impostare nel registro per il canale destro (unsigned char 0 = mute, 1= -95.5db 255 = +31.5db)
 * @return  -1: bus collision 
 */ 
signed char PGA23xx_send_register_value(unsigned char _r, unsigned char _l);

/** 
 * Abilita o disabilita mute via hardware pin
 * @param   _on_off: abilitazione o disabilitazione MUTE: PGA23xx_MUTE_ON/PGA23xx_MUTE_OFF (unsigned char)
 * @return  void
 */ 
void PGA23xx_hw_mute(unsigned char _on_off);

/** 
 * Abilita o disabilita zero crossing via hardware pin
 * @param   _on_off: abilitazione o disabilitazione zero crossing: PGA23xx_ZCEN_ON/PGA23xx_ZCEN_OFF (unsigned char)
 * @return  void
 */ 
void PGA23xx_zcen(unsigned char _on_off);

/** 
 * Restituisce il valore in dB dal valore inviato al registro
 * @param   _register_value: Valore inviato al registro (per canale) (unsigned char)
 * @return  valore in db dell'attenuazione/guadagno
 */
float PGA23xx_calc_db(unsigned char _register_value);